calc_rain: Average Percipitation 1995-2015

Description Usage Arguments Value Author(s)

View source: R/calc_rain.R

Description

This is a function that determines the wet and dry year between 1995 and 2015

Usage

1

Arguments

rain_data

is from data within this package that has the average rainfall between 1995-2015

Value

rain_matrix (max and min rain years and their average)

Author(s)

Sidney


Sidneygerst/cliamte_package documentation built on March 24, 2020, 12:03 a.m.