calc_temp: Average Temperature 1995-2015

Description Usage Arguments Value Author(s)

View source: R/calc_temp.R

Description

This is a function that determines the cold and hot years between 1995 and 2015

Usage

1

Arguments

temp_data

is from data within this package that has the average temperature between 1995-2015

Value

rain_matrix (max and min rain years and their average)

Author(s)

Sidney


Sidneygerst/cliamte_package documentation built on March 24, 2020, 12:03 a.m.