Description Usage Arguments Value Author(s)
This is a function that determines the cold and hot years between 1995 and 2015
1 |
temp_data |
is from data within this package that has the average temperature between 1995-2015 |
rain_matrix (max and min rain years and their average)
Sidney
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.